# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gqldb.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'gqldb.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bgqldb.proto\x12\x05gqldb\"N\n\nTypedValue\x12!\n\x04type\x18\x01 \x01(\x0e\x32\x13.gqldb.PropertyType\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x0f\n\x07is_null\x18\x03 \x01(\x08\";\n\tParameter\x12\x0c\n\x04name\x18\x01 \x01(\t\x12 \n\x05value\x18\x02 \x01(\x0b\x32\x11.gqldb.TypedValue\"(\n\x03Row\x12!\n\x06values\x18\x01 \x03(\x0b\x32\x11.gqldb.TypedValue\"I\n\x0cLoginRequest\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x15\n\rdefault_graph\x18\x03 \x01(\t\"J\n\rLoginResponse\x12\x12\n\nsession_id\x18\x01 \x01(\x04\x12\x16\n\x0eserver_version\x18\x02 \x01(\t\x12\r\n\x05roles\x18\x03 \x03(\t\"\x0f\n\rLogoutRequest\"!\n\x0eLogoutResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"\r\n\x0bPingRequest\"\"\n\x0cPingResponse\x12\x12\n\nlatency_ns\x18\x01 \x01(\x03\"\xbd\x01\n\nGqlRequest\x12\x0b\n\x03gql\x18\x01 \x01(\t\x12\x12\n\ngraph_name\x18\x02 \x01(\t\x12$\n\nparameters\x18\x03 \x03(\x0b\x32\x10.gqldb.Parameter\x12\x12\n\nsession_id\x18\x04 \x01(\x04\x12\x16\n\x0etransaction_id\x18\x05 \x01(\x04\x12\x0f\n\x07timeout\x18\x06 \x01(\x05\x12\x11\n\tread_only\x18\x07 \x01(\x08\x12\x18\n\x10max_path_results\x18\x08 \x01(\x03\"\x86\x01\n\x0bGqlResponse\x12\x0f\n\x07\x63olumns\x18\x01 \x03(\t\x12\x18\n\x04rows\x18\x02 \x03(\x0b\x32\n.gqldb.Row\x12\x11\n\trow_count\x18\x03 \x01(\x03\x12\x10\n\x08has_more\x18\x04 \x01(\x08\x12\x10\n\x08warnings\x18\x05 \x03(\t\x12\x15\n\rrows_affected\x18\x06 \x01(\x03\"\x1f\n\x0f\x45xplainResponse\x12\x0c\n\x04plan\x18\x01 \x01(\t\"\"\n\x0fProfileResponse\x12\x0f\n\x07profile\x18\x01 \x01(\t\"\xa1\x01\n\x08NodeData\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06labels\x18\x02 \x03(\t\x12\x33\n\nproperties\x18\x03 \x03(\x0b\x32\x1f.gqldb.NodeData.PropertiesEntry\x1a\x44\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12 \n\x05value\x18\x02 \x01(\x0b\x32\x11.gqldb.TypedValue:\x02\x38\x01\"\xbe\x01\n\x08\x45\x64geData\x12\r\n\x05label\x18\x01 \x01(\t\x12\x14\n\x0c\x66rom_node_id\x18\x02 \x01(\t\x12\x12\n\nto_node_id\x18\x03 \x01(\t\x12\x33\n\nproperties\x18\x04 \x03(\x0b\x32\x1f.gqldb.EdgeData.PropertiesEntry\x1a\x44\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12 \n\x05value\x18\x02 \x01(\x0b\x32\x11.gqldb.TypedValue:\x02\x38\x01\"+\n\x16\x42ulkCreateNodesOptions\x12\x11\n\toverwrite\x18\x01 \x01(\x08\"4\n\x16\x42ulkCreateEdgesOptions\x12\x1a\n\x12skip_invalid_nodes\x18\x01 \x01(\x08\"\x98\x01\n\x12InsertNodesRequest\x12\x12\n\ngraph_name\x18\x01 \x01(\t\x12\x1e\n\x05nodes\x18\x02 \x03(\x0b\x32\x0f.gqldb.NodeData\x12.\n\x07options\x18\x03 \x01(\x0b\x32\x1d.gqldb.BulkCreateNodesOptions\x12\x1e\n\x16\x62ulk_import_session_id\x18\x04 \x01(\t\"]\n\x13InsertNodesResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x10\n\x08node_ids\x18\x02 \x03(\t\x12\x12\n\nnode_count\x18\x03 \x01(\x03\x12\x0f\n\x07message\x18\x04 \x01(\t\"\x98\x01\n\x12InsertEdgesRequest\x12\x12\n\ngraph_name\x18\x01 \x01(\t\x12\x1e\n\x05\x65\x64ges\x18\x02 \x03(\x0b\x32\x0f.gqldb.EdgeData\x12.\n\x07options\x18\x03 \x01(\x0b\x32\x1d.gqldb.BulkCreateEdgesOptions\x12\x1e\n\x16\x62ulk_import_session_id\x18\x04 \x01(\t\"t\n\x13InsertEdgesResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x10\n\x08\x65\x64ge_ids\x18\x02 \x03(\t\x12\x12\n\nedge_count\x18\x03 \x01(\x03\x12\x0f\n\x07message\x18\x04 \x01(\t\x12\x15\n\rskipped_count\x18\x05 \x01(\x03\"Y\n\x12\x44\x65leteNodesRequest\x12\x12\n\ngraph_name\x18\x01 \x01(\t\x12\x10\n\x08node_ids\x18\x02 \x03(\t\x12\x0e\n\x06labels\x18\x03 \x03(\t\x12\r\n\x05where\x18\x04 \x01(\t\"N\n\x13\x44\x65leteNodesResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x15\n\rdeleted_count\x18\x02 \x01(\x03\x12\x0f\n\x07message\x18\x03 \x01(\t\"X\n\x12\x44\x65leteEdgesRequest\x12\x12\n\ngraph_name\x18\x01 \x01(\t\x12\x10\n\x08\x65\x64ge_ids\x18\x02 \x03(\t\x12\r\n\x05label\x18\x03 \x01(\t\x12\r\n\x05where\x18\x04 \x01(\t\"N\n\x13\x44\x65leteEdgesResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x15\n\rdeleted_count\x18\x02 \x01(\x03\x12\x0f\n\x07message\x18\x03 \x01(\t\"\xa7\x01\n\rExportRequest\x12\x12\n\ngraph_name\x18\x01 \x01(\t\x12\x12\n\nbatch_size\x18\x02 \x01(\x05\x12\x14\n\x0c\x65xport_nodes\x18\x03 \x01(\x08\x12\x14\n\x0c\x65xport_edges\x18\x04 \x01(\x08\x12\x13\n\x0bnode_labels\x18\x05 \x03(\t\x12\x13\n\x0b\x65\x64ge_labels\x18\x06 \x03(\t\x12\x18\n\x10include_metadata\x18\x07 \x01(\x08\"S\n\x0e\x45xportResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x10\n\x08is_final\x18\x02 \x01(\x08\x12!\n\x05stats\x18\x03 \x01(\x0b\x32\x12.gqldb.ExportStats\"i\n\x0b\x45xportStats\x12\x16\n\x0enodes_exported\x18\x01 \x01(\x03\x12\x16\n\x0e\x65\x64ges_exported\x18\x02 \x01(\x03\x12\x15\n\rbytes_written\x18\x03 \x01(\x03\x12\x13\n\x0b\x64uration_ms\x18\x04 \x01(\x03\"]\n\x12\x43reateGraphRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12$\n\ngraph_type\x18\x02 \x01(\x0e\x32\x10.gqldb.GraphType\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\"7\n\x13\x43reateGraphResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"3\n\x10\x44ropGraphRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tif_exists\x18\x02 \x01(\x08\"5\n\x11\x44ropGraphResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"7\n\x0fUseGraphRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x16\n\nsession_id\x18\x02 \x01(\x04\x42\x02\x18\x01\"4\n\x10UseGraphResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"\x13\n\x11ListGraphsRequest\"6\n\x12ListGraphsResponse\x12 \n\x06graphs\x18\x01 \x03(\x0b\x32\x10.gqldb.GraphInfo\"#\n\x13GetGraphInfoRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"6\n\x14GetGraphInfoResponse\x12\x1e\n\x04info\x18\x01 \x01(\x0b\x32\x10.gqldb.GraphInfo\"|\n\tGraphInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12$\n\ngraph_type\x18\x02 \x01(\x0e\x32\x10.gqldb.GraphType\x12\x12\n\nnode_count\x18\x03 \x01(\x03\x12\x12\n\nedge_count\x18\x04 \x01(\x03\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\"^\n\x0c\x42\x65ginRequest\x12\x16\n\nsession_id\x18\x01 \x01(\x04\x42\x02\x18\x01\x12\x12\n\ngraph_name\x18\x02 \x01(\t\x12\x11\n\tread_only\x18\x03 \x01(\x08\x12\x0f\n\x07timeout\x18\x04 \x01(\x05\"8\n\rBeginResponse\x12\x16\n\x0etransaction_id\x18\x01 \x01(\x04\x12\x0f\n\x07message\x18\x02 \x01(\t\"?\n\rCommitRequest\x12\x16\n\nsession_id\x18\x01 \x01(\x04\x42\x02\x18\x01\x12\x16\n\x0etransaction_id\x18\x02 \x01(\x04\"2\n\x0e\x43ommitResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"A\n\x0fRollbackRequest\x12\x16\n\nsession_id\x18\x01 \x01(\x04\x42\x02\x18\x01\x12\x16\n\x0etransaction_id\x18\x02 \x01(\x04\"4\n\x10RollbackResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"K\n\x17ListTransactionsRequest\x12\x16\n\nsession_id\x18\x01 \x01(\x04\x42\x02\x18\x01\x12\x18\n\x10\x61ll_transactions\x18\x02 \x01(\x08\"H\n\x18ListTransactionsResponse\x12,\n\x0ctransactions\x18\x01 \x03(\x0b\x32\x16.gqldb.TransactionInfo\"\xa5\x01\n\x0fTransactionInfo\x12\x16\n\x0etransaction_id\x18\x01 \x01(\x04\x12\x12\n\nsession_id\x18\x02 \x01(\x04\x12\x12\n\ngraph_name\x18\x03 \x01(\t\x12\x11\n\tread_only\x18\x04 \x01(\x08\x12\x12\n\ncreated_at\x18\x05 \x01(\x03\x12\x13\n\x0b\x64uration_ms\x18\x06 \x01(\x03\x12\x16\n\x0einternal_tx_id\x18\x07 \x01(\t\"%\n\x12HealthCheckRequest\x12\x0f\n\x07service\x18\x01 \x01(\t\":\n\x13HealthCheckResponse\x12#\n\x06status\x18\x01 \x01(\x0e\x32\x13.gqldb.HealthStatus\"$\n\x13WarmupParserRequest\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\"8\n\x14WarmupParserResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"<\n\x14GetCacheStatsRequest\x12$\n\ncache_type\x18\x01 \x01(\x0e\x32\x10.gqldb.CacheType\"h\n\x12\x43\x61\x63heStatsResponse\x12\'\n\tast_stats\x18\x01 \x01(\x0b\x32\x14.gqldb.ASTCacheStats\x12)\n\nplan_stats\x18\x02 \x01(\x0b\x32\x15.gqldb.PlanCacheStats\"c\n\rASTCacheStats\x12\x0c\n\x04hits\x18\x01 \x01(\x04\x12\x0e\n\x06misses\x18\x02 \x01(\x04\x12\x11\n\tevictions\x18\x03 \x01(\x04\x12\x0f\n\x07\x65ntries\x18\x04 \x01(\x05\x12\x10\n\x08hit_rate\x18\x05 \x01(\x01\"`\n\x0ePlanCacheStats\x12\x0c\n\x04size\x18\x01 \x01(\x05\x12\x10\n\x08\x63\x61pacity\x18\x02 \x01(\x05\x12\x0c\n\x04hits\x18\x03 \x01(\x04\x12\x0e\n\x06misses\x18\x04 \x01(\x04\x12\x10\n\x08hit_rate\x18\x05 \x01(\x01\"9\n\x11\x43learCacheRequest\x12$\n\ncache_type\x18\x01 \x01(\x0e\x32\x10.gqldb.CacheType\"6\n\x12\x43learCacheResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"*\n\x14GetStatisticsRequest\x12\x12\n\ngraph_name\x18\x01 \x01(\t\"\xbe\x02\n\x15GetStatisticsResponse\x12\x12\n\nnode_count\x18\x01 \x01(\x04\x12\x12\n\nedge_count\x18\x02 \x01(\x04\x12\x43\n\x0clabel_counts\x18\x03 \x03(\x0b\x32-.gqldb.GetStatisticsResponse.LabelCountsEntry\x12L\n\x11\x65\x64ge_label_counts\x18\x04 \x03(\x0b\x32\x31.gqldb.GetStatisticsResponse.EdgeLabelCountsEntry\x1a\x32\n\x10LabelCountsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01\x1a\x36\n\x14\x45\x64geLabelCountsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01\"4\n InvalidatePermissionCacheRequest\x12\x10\n\x08username\x18\x01 \x01(\t\"4\n!InvalidatePermissionCacheResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"\x10\n\x0e\x43ompactRequest\"3\n\x0f\x43ompactResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"G\n\x1dWaitForComputeTopologyRequest\x12\x12\n\ngraph_name\x18\x01 \x01(\t\x12\x12\n\ntimeout_ms\x18\x02 \x01(\x03\"@\n\x1eWaitForComputeTopologyResponse\x12\r\n\x05ready\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"\xa6\x01\n\x16StartBulkImportRequest\x12\x12\n\ngraph_name\x18\x01 \x01(\t\x12\x18\n\x10\x63heckpoint_every\x18\x02 \x01(\x03\x12\x17\n\x0f\x65stimated_nodes\x18\x03 \x01(\x03\x12\x17\n\x0f\x65stimated_edges\x18\x04 \x01(\x03\x12\x15\n\rmemtable_size\x18\x05 \x01(\x03\x12\x15\n\rmax_memtables\x18\x06 \x01(\x05\"O\n\x17StartBulkImportResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\"\'\n\x11\x43heckpointRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\"k\n\x12\x43heckpointResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x14\n\x0crecord_count\x18\x02 \x01(\x03\x12\x1d\n\x15last_checkpoint_count\x18\x03 \x01(\x03\x12\x0f\n\x07message\x18\x04 \x01(\t\"*\n\x14\x45ndBulkImportRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\"P\n\x15\x45ndBulkImportResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x15\n\rtotal_records\x18\x02 \x01(\x03\x12\x0f\n\x07message\x18\x03 \x01(\t\",\n\x16\x41\x62ortBulkImportRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\";\n\x17\x41\x62ortBulkImportResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"0\n\x1aGetBulkImportStatusRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\"\xa4\x01\n\x1bGetBulkImportStatusResponse\x12\x11\n\tis_active\x18\x01 \x01(\x08\x12\x12\n\ngraph_name\x18\x02 \x01(\t\x12\x14\n\x0crecord_count\x18\x03 \x01(\x03\x12\x1d\n\x15last_checkpoint_count\x18\x04 \x01(\x03\x12\x12\n\ncreated_at\x18\x05 \x01(\x03\x12\x15\n\rlast_activity\x18\x06 \x01(\x03*\x90\x07\n\x0cPropertyType\x12\x17\n\x13PROPERTY_TYPE_UNSET\x10\x00\x12\x17\n\x13PROPERTY_TYPE_INT32\x10\x01\x12\x18\n\x14PROPERTY_TYPE_UINT32\x10\x02\x12\x17\n\x13PROPERTY_TYPE_INT64\x10\x03\x12\x18\n\x14PROPERTY_TYPE_UINT64\x10\x04\x12\x17\n\x13PROPERTY_TYPE_FLOAT\x10\x05\x12\x18\n\x14PROPERTY_TYPE_DOUBLE\x10\x06\x12\x18\n\x14PROPERTY_TYPE_STRING\x10\x07\x12\x1a\n\x16PROPERTY_TYPE_DATETIME\x10\x08\x12\x1b\n\x17PROPERTY_TYPE_TIMESTAMP\x10\t\x12\x16\n\x12PROPERTY_TYPE_TEXT\x10\n\x12\x16\n\x12PROPERTY_TYPE_BLOB\x10\x0b\x12\x17\n\x13PROPERTY_TYPE_POINT\x10\x0c\x12\x19\n\x15PROPERTY_TYPE_DECIMAL\x10\r\x12\x16\n\x12PROPERTY_TYPE_LIST\x10\x0e\x12\x15\n\x11PROPERTY_TYPE_SET\x10\x0f\x12\x15\n\x11PROPERTY_TYPE_MAP\x10\x10\x12\x16\n\x12PROPERTY_TYPE_NULL\x10\x11\x12\x16\n\x12PROPERTY_TYPE_BOOL\x10\x12\x12 \n\x1cPROPERTY_TYPE_LOCAL_DATETIME\x10\x13\x12 \n\x1cPROPERTY_TYPE_ZONED_DATETIME\x10\x14\x12\x16\n\x12PROPERTY_TYPE_DATE\x10\x15\x12\x1c\n\x18PROPERTY_TYPE_ZONED_TIME\x10\x16\x12\x1c\n\x18PROPERTY_TYPE_LOCAL_TIME\x10\x17\x12\x1f\n\x1bPROPERTY_TYPE_YEAR_TO_MONTH\x10\x18\x12\x1f\n\x1bPROPERTY_TYPE_DAY_TO_SECOND\x10\x19\x12\x18\n\x14PROPERTY_TYPE_RECORD\x10\x1a\x12\x19\n\x15PROPERTY_TYPE_POINT3D\x10\x1b\x12\x18\n\x14PROPERTY_TYPE_VECTOR\x10\x1c\x12\x17\n\x13PROPERTY_TYPE_TABLE\x10\x1d\x12\x16\n\x12PROPERTY_TYPE_PATH\x10\x1e\x12\x17\n\x13PROPERTY_TYPE_ERROR\x10\x1f\x12\x16\n\x12PROPERTY_TYPE_NODE\x10 \x12\x16\n\x12PROPERTY_TYPE_EDGE\x10!*P\n\tGraphType\x12\x13\n\x0fGRAPH_TYPE_OPEN\x10\x00\x12\x15\n\x11GRAPH_TYPE_CLOSED\x10\x01\x12\x17\n\x13GRAPH_TYPE_ONTOLOGY\x10\x02*\x86\x01\n\x0cHealthStatus\x12\x19\n\x15HEALTH_STATUS_UNKNOWN\x10\x00\x12\x19\n\x15HEALTH_STATUS_SERVING\x10\x01\x12\x1d\n\x19HEALTH_STATUS_NOT_SERVING\x10\x02\x12!\n\x1dHEALTH_STATUS_SERVICE_UNKNOWN\x10\x03*H\n\tCacheType\x12\x12\n\x0e\x43\x41\x43HE_TYPE_ALL\x10\x00\x12\x12\n\x0e\x43\x41\x43HE_TYPE_AST\x10\x01\x12\x13\n\x0f\x43\x41\x43HE_TYPE_PLAN\x10\x02\x32\xac\x01\n\x0eSessionService\x12\x32\n\x05Login\x12\x13.gqldb.LoginRequest\x1a\x14.gqldb.LoginResponse\x12\x35\n\x06Logout\x12\x14.gqldb.LogoutRequest\x1a\x15.gqldb.LogoutResponse\x12/\n\x04Ping\x12\x12.gqldb.PingRequest\x1a\x13.gqldb.PingResponse2\xde\x01\n\x0cQueryService\x12,\n\x03Gql\x12\x11.gqldb.GqlRequest\x1a\x12.gqldb.GqlResponse\x12\x34\n\tGqlStream\x12\x11.gqldb.GqlRequest\x1a\x12.gqldb.GqlResponse0\x01\x12\x34\n\x07\x45xplain\x12\x11.gqldb.GqlRequest\x1a\x16.gqldb.ExplainResponse\x12\x34\n\x07Profile\x12\x11.gqldb.GqlRequest\x1a\x16.gqldb.ProfileResponse2\xde\x02\n\x0b\x44\x61taService\x12\x44\n\x0bInsertNodes\x12\x19.gqldb.InsertNodesRequest\x1a\x1a.gqldb.InsertNodesResponse\x12\x44\n\x0bInsertEdges\x12\x19.gqldb.InsertEdgesRequest\x1a\x1a.gqldb.InsertEdgesResponse\x12\x44\n\x0b\x44\x65leteNodes\x12\x19.gqldb.DeleteNodesRequest\x1a\x1a.gqldb.DeleteNodesResponse\x12\x44\n\x0b\x44\x65leteEdges\x12\x19.gqldb.DeleteEdgesRequest\x1a\x1a.gqldb.DeleteEdgesResponse\x12\x37\n\x06\x45xport\x12\x14.gqldb.ExportRequest\x1a\x15.gqldb.ExportResponse0\x01\x32\xdd\x02\n\x0cGraphService\x12\x44\n\x0b\x43reateGraph\x12\x19.gqldb.CreateGraphRequest\x1a\x1a.gqldb.CreateGraphResponse\x12>\n\tDropGraph\x12\x17.gqldb.DropGraphRequest\x1a\x18.gqldb.DropGraphResponse\x12;\n\x08UseGraph\x12\x16.gqldb.UseGraphRequest\x1a\x17.gqldb.UseGraphResponse\x12\x41\n\nListGraphs\x12\x18.gqldb.ListGraphsRequest\x1a\x19.gqldb.ListGraphsResponse\x12G\n\x0cGetGraphInfo\x12\x1a.gqldb.GetGraphInfoRequest\x1a\x1b.gqldb.GetGraphInfoResponse2\x91\x02\n\x12TransactionService\x12\x32\n\x05\x42\x65gin\x12\x13.gqldb.BeginRequest\x1a\x14.gqldb.BeginResponse\x12\x35\n\x06\x43ommit\x12\x14.gqldb.CommitRequest\x1a\x15.gqldb.CommitResponse\x12;\n\x08Rollback\x12\x16.gqldb.RollbackRequest\x1a\x17.gqldb.RollbackResponse\x12S\n\x10ListTransactions\x12\x1e.gqldb.ListTransactionsRequest\x1a\x1f.gqldb.ListTransactionsResponse2\x8a\x01\n\x06Health\x12>\n\x05\x43heck\x12\x19.gqldb.HealthCheckRequest\x1a\x1a.gqldb.HealthCheckResponse\x12@\n\x05Watch\x12\x19.gqldb.HealthCheckRequest\x1a\x1a.gqldb.HealthCheckResponse0\x01\x32\xc0\x04\n\x0c\x41\x64minService\x12G\n\x0cWarmupParser\x12\x1a.gqldb.WarmupParserRequest\x1a\x1b.gqldb.WarmupParserResponse\x12G\n\rGetCacheStats\x12\x1b.gqldb.GetCacheStatsRequest\x1a\x19.gqldb.CacheStatsResponse\x12\x41\n\nClearCache\x12\x18.gqldb.ClearCacheRequest\x1a\x19.gqldb.ClearCacheResponse\x12J\n\rGetStatistics\x12\x1b.gqldb.GetStatisticsRequest\x1a\x1c.gqldb.GetStatisticsResponse\x12n\n\x19InvalidatePermissionCache\x12\'.gqldb.InvalidatePermissionCacheRequest\x1a(.gqldb.InvalidatePermissionCacheResponse\x12\x38\n\x07\x43ompact\x12\x15.gqldb.CompactRequest\x1a\x16.gqldb.CompactResponse\x12\x65\n\x16WaitForComputeTopology\x12$.gqldb.WaitForComputeTopologyRequest\x1a%.gqldb.WaitForComputeTopologyResponse2\xa4\x03\n\x11\x42ulkImportService\x12P\n\x0fStartBulkImport\x12\x1d.gqldb.StartBulkImportRequest\x1a\x1e.gqldb.StartBulkImportResponse\x12\x41\n\nCheckpoint\x12\x18.gqldb.CheckpointRequest\x1a\x19.gqldb.CheckpointResponse\x12J\n\rEndBulkImport\x12\x1b.gqldb.EndBulkImportRequest\x1a\x1c.gqldb.EndBulkImportResponse\x12P\n\x0f\x41\x62ortBulkImport\x12\x1d.gqldb.AbortBulkImportRequest\x1a\x1e.gqldb.AbortBulkImportResponse\x12\\\n\x13GetBulkImportStatus\x12!.gqldb.GetBulkImportStatusRequest\x1a\".gqldb.GetBulkImportStatusResponseB\'Z%github.com/zhangjsff/gqldb-grpc/protob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gqldb_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z%github.com/zhangjsff/gqldb-grpc/proto'
  _globals['_NODEDATA_PROPERTIESENTRY']._loaded_options = None
  _globals['_NODEDATA_PROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_EDGEDATA_PROPERTIESENTRY']._loaded_options = None
  _globals['_EDGEDATA_PROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_USEGRAPHREQUEST'].fields_by_name['session_id']._loaded_options = None
  _globals['_USEGRAPHREQUEST'].fields_by_name['session_id']._serialized_options = b'\030\001'
  _globals['_BEGINREQUEST'].fields_by_name['session_id']._loaded_options = None
  _globals['_BEGINREQUEST'].fields_by_name['session_id']._serialized_options = b'\030\001'
  _globals['_COMMITREQUEST'].fields_by_name['session_id']._loaded_options = None
  _globals['_COMMITREQUEST'].fields_by_name['session_id']._serialized_options = b'\030\001'
  _globals['_ROLLBACKREQUEST'].fields_by_name['session_id']._loaded_options = None
  _globals['_ROLLBACKREQUEST'].fields_by_name['session_id']._serialized_options = b'\030\001'
  _globals['_LISTTRANSACTIONSREQUEST'].fields_by_name['session_id']._loaded_options = None
  _globals['_LISTTRANSACTIONSREQUEST'].fields_by_name['session_id']._serialized_options = b'\030\001'
  _globals['_GETSTATISTICSRESPONSE_LABELCOUNTSENTRY']._loaded_options = None
  _globals['_GETSTATISTICSRESPONSE_LABELCOUNTSENTRY']._serialized_options = b'8\001'
  _globals['_GETSTATISTICSRESPONSE_EDGELABELCOUNTSENTRY']._loaded_options = None
  _globals['_GETSTATISTICSRESPONSE_EDGELABELCOUNTSENTRY']._serialized_options = b'8\001'
  _globals['_PROPERTYTYPE']._serialized_start=6128
  _globals['_PROPERTYTYPE']._serialized_end=7040
  _globals['_GRAPHTYPE']._serialized_start=7042
  _globals['_GRAPHTYPE']._serialized_end=7122
  _globals['_HEALTHSTATUS']._serialized_start=7125
  _globals['_HEALTHSTATUS']._serialized_end=7259
  _globals['_CACHETYPE']._serialized_start=7261
  _globals['_CACHETYPE']._serialized_end=7333
  _globals['_TYPEDVALUE']._serialized_start=22
  _globals['_TYPEDVALUE']._serialized_end=100
  _globals['_PARAMETER']._serialized_start=102
  _globals['_PARAMETER']._serialized_end=161
  _globals['_ROW']._serialized_start=163
  _globals['_ROW']._serialized_end=203
  _globals['_LOGINREQUEST']._serialized_start=205
  _globals['_LOGINREQUEST']._serialized_end=278
  _globals['_LOGINRESPONSE']._serialized_start=280
  _globals['_LOGINRESPONSE']._serialized_end=354
  _globals['_LOGOUTREQUEST']._serialized_start=356
  _globals['_LOGOUTREQUEST']._serialized_end=371
  _globals['_LOGOUTRESPONSE']._serialized_start=373
  _globals['_LOGOUTRESPONSE']._serialized_end=406
  _globals['_PINGREQUEST']._serialized_start=408
  _globals['_PINGREQUEST']._serialized_end=421
  _globals['_PINGRESPONSE']._serialized_start=423
  _globals['_PINGRESPONSE']._serialized_end=457
  _globals['_GQLREQUEST']._serialized_start=460
  _globals['_GQLREQUEST']._serialized_end=649
  _globals['_GQLRESPONSE']._serialized_start=652
  _globals['_GQLRESPONSE']._serialized_end=786
  _globals['_EXPLAINRESPONSE']._serialized_start=788
  _globals['_EXPLAINRESPONSE']._serialized_end=819
  _globals['_PROFILERESPONSE']._serialized_start=821
  _globals['_PROFILERESPONSE']._serialized_end=855
  _globals['_NODEDATA']._serialized_start=858
  _globals['_NODEDATA']._serialized_end=1019
  _globals['_NODEDATA_PROPERTIESENTRY']._serialized_start=951
  _globals['_NODEDATA_PROPERTIESENTRY']._serialized_end=1019
  _globals['_EDGEDATA']._serialized_start=1022
  _globals['_EDGEDATA']._serialized_end=1212
  _globals['_EDGEDATA_PROPERTIESENTRY']._serialized_start=951
  _globals['_EDGEDATA_PROPERTIESENTRY']._serialized_end=1019
  _globals['_BULKCREATENODESOPTIONS']._serialized_start=1214
  _globals['_BULKCREATENODESOPTIONS']._serialized_end=1257
  _globals['_BULKCREATEEDGESOPTIONS']._serialized_start=1259
  _globals['_BULKCREATEEDGESOPTIONS']._serialized_end=1311
  _globals['_INSERTNODESREQUEST']._serialized_start=1314
  _globals['_INSERTNODESREQUEST']._serialized_end=1466
  _globals['_INSERTNODESRESPONSE']._serialized_start=1468
  _globals['_INSERTNODESRESPONSE']._serialized_end=1561
  _globals['_INSERTEDGESREQUEST']._serialized_start=1564
  _globals['_INSERTEDGESREQUEST']._serialized_end=1716
  _globals['_INSERTEDGESRESPONSE']._serialized_start=1718
  _globals['_INSERTEDGESRESPONSE']._serialized_end=1834
  _globals['_DELETENODESREQUEST']._serialized_start=1836
  _globals['_DELETENODESREQUEST']._serialized_end=1925
  _globals['_DELETENODESRESPONSE']._serialized_start=1927
  _globals['_DELETENODESRESPONSE']._serialized_end=2005
  _globals['_DELETEEDGESREQUEST']._serialized_start=2007
  _globals['_DELETEEDGESREQUEST']._serialized_end=2095
  _globals['_DELETEEDGESRESPONSE']._serialized_start=2097
  _globals['_DELETEEDGESRESPONSE']._serialized_end=2175
  _globals['_EXPORTREQUEST']._serialized_start=2178
  _globals['_EXPORTREQUEST']._serialized_end=2345
  _globals['_EXPORTRESPONSE']._serialized_start=2347
  _globals['_EXPORTRESPONSE']._serialized_end=2430
  _globals['_EXPORTSTATS']._serialized_start=2432
  _globals['_EXPORTSTATS']._serialized_end=2537
  _globals['_CREATEGRAPHREQUEST']._serialized_start=2539
  _globals['_CREATEGRAPHREQUEST']._serialized_end=2632
  _globals['_CREATEGRAPHRESPONSE']._serialized_start=2634
  _globals['_CREATEGRAPHRESPONSE']._serialized_end=2689
  _globals['_DROPGRAPHREQUEST']._serialized_start=2691
  _globals['_DROPGRAPHREQUEST']._serialized_end=2742
  _globals['_DROPGRAPHRESPONSE']._serialized_start=2744
  _globals['_DROPGRAPHRESPONSE']._serialized_end=2797
  _globals['_USEGRAPHREQUEST']._serialized_start=2799
  _globals['_USEGRAPHREQUEST']._serialized_end=2854
  _globals['_USEGRAPHRESPONSE']._serialized_start=2856
  _globals['_USEGRAPHRESPONSE']._serialized_end=2908
  _globals['_LISTGRAPHSREQUEST']._serialized_start=2910
  _globals['_LISTGRAPHSREQUEST']._serialized_end=2929
  _globals['_LISTGRAPHSRESPONSE']._serialized_start=2931
  _globals['_LISTGRAPHSRESPONSE']._serialized_end=2985
  _globals['_GETGRAPHINFOREQUEST']._serialized_start=2987
  _globals['_GETGRAPHINFOREQUEST']._serialized_end=3022
  _globals['_GETGRAPHINFORESPONSE']._serialized_start=3024
  _globals['_GETGRAPHINFORESPONSE']._serialized_end=3078
  _globals['_GRAPHINFO']._serialized_start=3080
  _globals['_GRAPHINFO']._serialized_end=3204
  _globals['_BEGINREQUEST']._serialized_start=3206
  _globals['_BEGINREQUEST']._serialized_end=3300
  _globals['_BEGINRESPONSE']._serialized_start=3302
  _globals['_BEGINRESPONSE']._serialized_end=3358
  _globals['_COMMITREQUEST']._serialized_start=3360
  _globals['_COMMITREQUEST']._serialized_end=3423
  _globals['_COMMITRESPONSE']._serialized_start=3425
  _globals['_COMMITRESPONSE']._serialized_end=3475
  _globals['_ROLLBACKREQUEST']._serialized_start=3477
  _globals['_ROLLBACKREQUEST']._serialized_end=3542
  _globals['_ROLLBACKRESPONSE']._serialized_start=3544
  _globals['_ROLLBACKRESPONSE']._serialized_end=3596
  _globals['_LISTTRANSACTIONSREQUEST']._serialized_start=3598
  _globals['_LISTTRANSACTIONSREQUEST']._serialized_end=3673
  _globals['_LISTTRANSACTIONSRESPONSE']._serialized_start=3675
  _globals['_LISTTRANSACTIONSRESPONSE']._serialized_end=3747
  _globals['_TRANSACTIONINFO']._serialized_start=3750
  _globals['_TRANSACTIONINFO']._serialized_end=3915
  _globals['_HEALTHCHECKREQUEST']._serialized_start=3917
  _globals['_HEALTHCHECKREQUEST']._serialized_end=3954
  _globals['_HEALTHCHECKRESPONSE']._serialized_start=3956
  _globals['_HEALTHCHECKRESPONSE']._serialized_end=4014
  _globals['_WARMUPPARSERREQUEST']._serialized_start=4016
  _globals['_WARMUPPARSERREQUEST']._serialized_end=4052
  _globals['_WARMUPPARSERRESPONSE']._serialized_start=4054
  _globals['_WARMUPPARSERRESPONSE']._serialized_end=4110
  _globals['_GETCACHESTATSREQUEST']._serialized_start=4112
  _globals['_GETCACHESTATSREQUEST']._serialized_end=4172
  _globals['_CACHESTATSRESPONSE']._serialized_start=4174
  _globals['_CACHESTATSRESPONSE']._serialized_end=4278
  _globals['_ASTCACHESTATS']._serialized_start=4280
  _globals['_ASTCACHESTATS']._serialized_end=4379
  _globals['_PLANCACHESTATS']._serialized_start=4381
  _globals['_PLANCACHESTATS']._serialized_end=4477
  _globals['_CLEARCACHEREQUEST']._serialized_start=4479
  _globals['_CLEARCACHEREQUEST']._serialized_end=4536
  _globals['_CLEARCACHERESPONSE']._serialized_start=4538
  _globals['_CLEARCACHERESPONSE']._serialized_end=4592
  _globals['_GETSTATISTICSREQUEST']._serialized_start=4594
  _globals['_GETSTATISTICSREQUEST']._serialized_end=4636
  _globals['_GETSTATISTICSRESPONSE']._serialized_start=4639
  _globals['_GETSTATISTICSRESPONSE']._serialized_end=4957
  _globals['_GETSTATISTICSRESPONSE_LABELCOUNTSENTRY']._serialized_start=4851
  _globals['_GETSTATISTICSRESPONSE_LABELCOUNTSENTRY']._serialized_end=4901
  _globals['_GETSTATISTICSRESPONSE_EDGELABELCOUNTSENTRY']._serialized_start=4903
  _globals['_GETSTATISTICSRESPONSE_EDGELABELCOUNTSENTRY']._serialized_end=4957
  _globals['_INVALIDATEPERMISSIONCACHEREQUEST']._serialized_start=4959
  _globals['_INVALIDATEPERMISSIONCACHEREQUEST']._serialized_end=5011
  _globals['_INVALIDATEPERMISSIONCACHERESPONSE']._serialized_start=5013
  _globals['_INVALIDATEPERMISSIONCACHERESPONSE']._serialized_end=5065
  _globals['_COMPACTREQUEST']._serialized_start=5067
  _globals['_COMPACTREQUEST']._serialized_end=5083
  _globals['_COMPACTRESPONSE']._serialized_start=5085
  _globals['_COMPACTRESPONSE']._serialized_end=5136
  _globals['_WAITFORCOMPUTETOPOLOGYREQUEST']._serialized_start=5138
  _globals['_WAITFORCOMPUTETOPOLOGYREQUEST']._serialized_end=5209
  _globals['_WAITFORCOMPUTETOPOLOGYRESPONSE']._serialized_start=5211
  _globals['_WAITFORCOMPUTETOPOLOGYRESPONSE']._serialized_end=5275
  _globals['_STARTBULKIMPORTREQUEST']._serialized_start=5278
  _globals['_STARTBULKIMPORTREQUEST']._serialized_end=5444
  _globals['_STARTBULKIMPORTRESPONSE']._serialized_start=5446
  _globals['_STARTBULKIMPORTRESPONSE']._serialized_end=5525
  _globals['_CHECKPOINTREQUEST']._serialized_start=5527
  _globals['_CHECKPOINTREQUEST']._serialized_end=5566
  _globals['_CHECKPOINTRESPONSE']._serialized_start=5568
  _globals['_CHECKPOINTRESPONSE']._serialized_end=5675
  _globals['_ENDBULKIMPORTREQUEST']._serialized_start=5677
  _globals['_ENDBULKIMPORTREQUEST']._serialized_end=5719
  _globals['_ENDBULKIMPORTRESPONSE']._serialized_start=5721
  _globals['_ENDBULKIMPORTRESPONSE']._serialized_end=5801
  _globals['_ABORTBULKIMPORTREQUEST']._serialized_start=5803
  _globals['_ABORTBULKIMPORTREQUEST']._serialized_end=5847
  _globals['_ABORTBULKIMPORTRESPONSE']._serialized_start=5849
  _globals['_ABORTBULKIMPORTRESPONSE']._serialized_end=5908
  _globals['_GETBULKIMPORTSTATUSREQUEST']._serialized_start=5910
  _globals['_GETBULKIMPORTSTATUSREQUEST']._serialized_end=5958
  _globals['_GETBULKIMPORTSTATUSRESPONSE']._serialized_start=5961
  _globals['_GETBULKIMPORTSTATUSRESPONSE']._serialized_end=6125
  _globals['_SESSIONSERVICE']._serialized_start=7336
  _globals['_SESSIONSERVICE']._serialized_end=7508
  _globals['_QUERYSERVICE']._serialized_start=7511
  _globals['_QUERYSERVICE']._serialized_end=7733
  _globals['_DATASERVICE']._serialized_start=7736
  _globals['_DATASERVICE']._serialized_end=8086
  _globals['_GRAPHSERVICE']._serialized_start=8089
  _globals['_GRAPHSERVICE']._serialized_end=8438
  _globals['_TRANSACTIONSERVICE']._serialized_start=8441
  _globals['_TRANSACTIONSERVICE']._serialized_end=8714
  _globals['_HEALTH']._serialized_start=8717
  _globals['_HEALTH']._serialized_end=8855
  _globals['_ADMINSERVICE']._serialized_start=8858
  _globals['_ADMINSERVICE']._serialized_end=9434
  _globals['_BULKIMPORTSERVICE']._serialized_start=9437
  _globals['_BULKIMPORTSERVICE']._serialized_end=9857
# @@protoc_insertion_point(module_scope)
